@@ -1473,6 +1473,24 @@ def runtestswithappsurify(*args):
             reporttype = "directory"
             deletereports = "false"
 
+        # need to set system property in gradle file for test
+        # systemProperty("cucumber.filter.name", findProperty("appsurifytests"))
+        # command sets appsurifytests which then gets run
+        # to rungradlew test -Pappsurifytests=".*another.*"
+        if testtemplate == "gradle cucumber":
+            testseparator = "|"
+        # startrunspecific = "gradle test --test '"
+            startrunspecific = "gradle test "
+            prefixtest = ""
+            postfixtest = ""
+            #endrunspecific = "'"
+            startrunall = "gradle test "
+            report = "./build/test-results/"
+            reporttype = "directory"
+            deletereports = "false"
+            endrunspecific = "\""
+            endspecificrun = " -Pappsurifytests=\""
+
         if testtemplate == "mvn":
             testseparator = ","
             addtestsuitename = "true"
